pub struct PubSubConfig {
pub enabled: bool,
pub project_id: String,
pub endpoint: Option<String>,
pub credentials: Option<String>,
}Fields
enabled: boolWhen false, the plugin does not connect to Pub/Sub or register consumers.
project_id: StringGCP project id used to expand short subscription and topic names.
endpoint: Option<String>Optional API endpoint (for example the Pub/Sub emulator).
credentials: Option<String>Optional path to a service account or ADC JSON key file.