#[non_exhaustive]pub enum InputFormat {
TextFormat(Box<TextFormat>),
AvroFormat(Box<AvroFormat>),
PubsubAvroFormat(Box<PubSubAvroFormat>),
}Expand description
Defaults to text format.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TextFormat(Box<TextFormat>)
Optional. Data from Cloud Storage will be interpreted as text.
AvroFormat(Box<AvroFormat>)
Optional. Data from Cloud Storage will be interpreted in Avro format.
PubsubAvroFormat(Box<PubSubAvroFormat>)
Optional. It will be assumed data from Cloud Storage was written via Cloud Storage subscriptions.