#[non_exhaustive]pub struct TextFormat {
pub delimiter: Option<String>,
/* private fields */
}Expand description
Configuration for reading Cloud Storage data in text format. Each line of
text as specified by the delimiter will be set to the data field of a
Pub/Sub message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delimiter: Option<String>Optional. When unset, ‘\n’ is used.
Implementations
Sourceimpl TextFormat
impl TextFormat
pub fn new() -> TextFormat
Sourcepub fn set_delimiter<T>(self, v: T) -> TextFormat
pub fn set_delimiter<T>(self, v: T) -> TextFormat
Sourcepub fn set_or_clear_delimiter<T>(self, v: Option<T>) -> TextFormat
pub fn set_or_clear_delimiter<T>(self, v: Option<T>) -> TextFormat